"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const utils_js_1 = require("./utils.js");
const loggingValues = {
    fatal: 0,
    error: 1,
    warn: 2,
    important: 3,
    success: 4,
    info: 5,
    verbose: 6
};
class OurLogging {
    #logLevel = 6;
    #logFileName;
    #separeteLogsByDate = false;
    /**
     * If enabled will sort all new logs in directory by MONTH_YYYY with names DD.log
     * eg October_2022/31.log
     */
    setSeparateLogsByDate(value) {
        this.#separeteLogsByDate = value;
    }
    /**
     * logs by level decrease: 'fatal' | 'error' | 'warn' | 'important' | 'info' | 'success' | 'verbose'
     * @param level log that you want to see in console
     * @example logging.setLogLevel('important')
     * // After that only fatal, error, warn, important logs will shown
     */
    setLogLevel(newLevel) { this.#logLevel = loggingValues[newLevel]; }
    /**
     * @param name full path to file with logs
     */
    setLogfileName(name) { this.#logFileName = name; }
    /**
     * Use only for most important staff like db connection
     * Will show stack in console
     * @param text will be seen first by user
     * @param stackTrace will be showed after text and logged into file
     * @example throw logging.fatal('DB connection error', err.stack)
     * @returns Error object with text
     */
    fatal(text, stackTrace = '') {
        const currentTime = (0, utils_js_1.getDateTime)();
        let logText = `\n[ FATAL ERROR ] ${currentTime} | ${text}  ${stackTrace}`;
        (0, utils_js_1.coloredConsoleLog)('[ FATAL ERROR ] ', 'carmine', `${currentTime} | ${text} ${stackTrace}`);
        (0, utils_js_1.logTextToFile)(logText, this.#logFileName, this.#separeteLogsByDate);
        return new Error(logText);
    }
    /**
     * Important but not cicritical errors
     * @param text
     * @returns Error object with error text
     */
    error(...texts) {
        if (!this.#aboveSelectedLogLevel('error'))
            return;
        const currentTime = (0, utils_js_1.getDateTime)();
        (0, utils_js_1.coloredConsoleLog)('[ ERROR ] ', 'scarlet', `${currentTime} | `, ...texts);
        const textsInNormalRepresentation = (0, utils_js_1.normalizeTexts)(...texts);
        const textsForPrint = textsInNormalRepresentation.join(' ');
        let logText = `\n[ ERROR ] ${currentTime} | ${textsForPrint}`;
        (0, utils_js_1.logTextToFile)(logText, this.#logFileName, this.#separeteLogsByDate);
        return new Error(logText);
    }
    /**
     * Some suspicious things, noticeable in console
     * EG on server start database logging turn off
     * @param text
     */
    warn(...texts) {
        if (!this.#aboveSelectedLogLevel('warn'))
            return;
        const currentTime = (0, utils_js_1.getDateTime)();
        (0, utils_js_1.coloredConsoleLog)('[ WARNING ] ', 'yellow', `${currentTime} | `, ...texts);
        const textsInNormalRepresentation = (0, utils_js_1.normalizeTexts)(...texts);
        const textsForPrint = textsInNormalRepresentation.join(' ');
        let logText = `\n[ WARNING ] ${currentTime} | ${textsForPrint}`;
        (0, utils_js_1.logTextToFile)(logText, this.#logFileName, this.#separeteLogsByDate);
    }
    /**
     * Some important things, noticeable in console
     * @param text
     */
    important(...texts) {
        if (!this.#aboveSelectedLogLevel('important'))
            return;
        const currentTime = (0, utils_js_1.getDateTime)();
        (0, utils_js_1.coloredConsoleLog)('[ IMPORTANT ] ', 'blue', `${currentTime} | `, ...texts);
        const textsInNormalRepresentation = (0, utils_js_1.normalizeTexts)(...texts);
        const textsForPrint = textsInNormalRepresentation.join(' ');
        let logText = `\n[ IMPORTANT ] ${currentTime} | ${textsForPrint}`;
        (0, utils_js_1.logTextToFile)(logText, this.#logFileName, this.#separeteLogsByDate);
    }
    /**
     * Not noticeable in console
     * @param text
     */
    info(...texts) {
        if (!this.#aboveSelectedLogLevel('info'))
            return;
        const currentTime = (0, utils_js_1.getDateTime)();
        (0, utils_js_1.coloredConsoleLog)('[ INFO ] ', 'lightblue', `${currentTime} | `, ...texts);
        const textsInNormalRepresentation = (0, utils_js_1.normalizeTexts)(...texts);
        const textsForPrint = textsInNormalRepresentation.join(' ');
        let logText = `\n[ INFO ] ${currentTime} | ${textsForPrint}`;
        (0, utils_js_1.logTextToFile)(logText, this.#logFileName, this.#separeteLogsByDate);
    }
    /**
     * Gray colored log, use it for less important things than info.
     * You can turn off verbose logs (not show it in console, browser, file)
     * by setting log level to success: logging.setLogLevel('success')
     * @param text
     */
    verbose(...texts) {
        if (!this.#aboveSelectedLogLevel('verbose'))
            return;
        const currentTime = (0, utils_js_1.getDateTime)();
        (0, utils_js_1.coloredConsoleLog)('[ VERBOSE ] ', 'verbose_color', `${currentTime} | `, ...texts);
        const textsInNormalRepresentation = (0, utils_js_1.normalizeTexts)(...texts);
        const textsForPrint = textsInNormalRepresentation.join(' ');
        let logText = `\n[ VERBOSE ] ${currentTime} | ${textsForPrint}`;
        (0, utils_js_1.logTextToFile)(logText, this.#logFileName, this.#separeteLogsByDate);
    }
    /**
     * Noticeable in console, green color
     * @param text
     */
    success(...texts) {
        if (!this.#aboveSelectedLogLevel('success'))
            return;
        const currentTime = (0, utils_js_1.getDateTime)();
        (0, utils_js_1.coloredConsoleLog)('[ SUCCESS ] ', 'green', `${currentTime} | `, ...texts);
        const textsInNormalRepresentation = (0, utils_js_1.normalizeTexts)(...texts);
        const textsForPrint = textsInNormalRepresentation.join(' ');
        let logText = `\n[ SUCCESS ] ${currentTime} | ${textsForPrint}`;
        (0, utils_js_1.logTextToFile)(logText, this.#logFileName, this.#separeteLogsByDate);
    }
    #aboveSelectedLogLevel(testedLogLevel) {
        const selectedLogLevel = this.#logLevel;
        const wantedLogLevel = loggingValues[testedLogLevel];
        return wantedLogLevel <= selectedLogLevel;
    }
}
const logging = new OurLogging();
exports.default = logging;
